@@ -131,6 +131,8 @@ class Person(IngestedDataType):
     uploaded_by_user_id: Optional[str] = None
     last_enriched_at: Optional[str] = None
     telescope_icp: Optional[bool] = None
+    uprank: Optional[int] = None
+    downrank: Optional[int] = None
 
     @staticmethod
     def from_pdl(pdl_input: dict[str, any]) -> Optional['Person']:
@@ -191,5 +193,7 @@ class Person(IngestedDataType):
             tags=pdl_input.get('tags'),
             uploaded_by_user_id=None,
             last_enriched_at=get_current_datetime_aws_format(),
-            telescope_icp=None
+            telescope_icp=None,
+            uprank=None,
+            downrank=None
         )
