@@ -7,7 +7,7 @@ from telescope_sdk import SequenceStep
 from telescope_sdk.common import UserFacingDataType
 
 
-class ProspectSequenceStepEventType(Enum):
+class ProspectSequenceStepEventType(str, Enum):
     EMAIL_SENT = 'EMAIL_SENT'
 
 
