@@ -1,3 +1,4 @@
+from decimal import Decimal
 from enum import Enum
 from typing import Optional
 
@@ -23,7 +24,9 @@ class RecommendationRejectionReason(str, Enum):
 class Recommendation(UserFacingDataType):
     campaign_id: str
     person_id: str
+    recommendation_reason: str = None
     status: RecommendationStatus
-    relevance: float
+    resolved_at: str = None
+    relevance: Decimal = None
     rejection_reason: Optional[RecommendationRejectionReason] = None
     free_text_rejection_reason: Optional[str] = None
